@@ -6,7 +6,7 @@ import sqlalchemy
 
 from flask import current_app
 from flask import request
-from sqlalchemy_abc.helpers import columns
+from sqlalchemy_blender.helpers import columns
 
 from flask_atomic.dao.buffer.data import DataBuffer
 from flask_atomic.dao.buffer.query import QueryBuffer
